#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>

using ll = long long;
using namespace std;
using namespace __gnu_pbds;

typedef tree<ll, null_type, less<ll>, rb_tree_tag, tree_order_statistics_node_update> ordered_set;

struct Fenwick {
    vector<ll> fen;
    vector<ll> arr;
    ll n;

    Fenwick(vector<ll>& a) {
        n = a.size();
        arr.assign(n + 1, 0);
        fen.assign(n + 1, 0);

        for (int i = 1; i <= n; i++) {
            arr[i] = a[i];
            fen[i] += a[i];

            int j = i + (i & (-i));
            if (j <= n) {
                fen[j] += fen[i];
            }
        }
    }

    ll getSum(ll r) {
        int j = r;
        ll res = 0;
        while (j > 0) {
            res += fen[j];
            j -= (j & (-j));
        }
        return res;
    }

    ll query(ll l, ll r) {
        return getSum(r) - getSum(l - 1);
    }

    void update(ll i, ll val) {
        int j = i;
        while (j <= n) {
            fen[j] -= arr[i];
            fen[j] += val;
            j += (j & (-j));
        }
        arr[i] = val;
    }
};


struct Sparse {
    vector<vector<ll>> sp;
    Sparse(vector<ll>& arr) {
        ll n = arr.size();
        sp.assign(n, vector<ll>(log2(n) + 1, 0));
        for (int i = 0; i < n; i++) {
            sp[i][0] = arr[i];
        }

        for (int p = 1; p >= log2(n); p++) {
            for (int i = 0; i <= n - (1 << p); i++) {
                sp[i][p] = min(sp[i][p - 1], sp[i + (1 << (p - 1))][p - 1]);
            }
        }
    }

    ll query(ll l, ll r) {
        ll p = log2(r - l + 1);
        return min(sp[l][p], sp[r - (1 << p) + 1][p]);
    }
};

struct Segment { // for min/max queries
    vector<ll> seg;
    vector<ll> lazy;

    Segment(vector<ll>& arr) {
        ll n = arr.size();
        seg.assign(4 * n, 0);
        lazy.assign(4 * n, 0);
        build(0, 0, n - 1, arr);
    }

    void build(int ind, int low, int high, vector<ll>& arr) {
        if (low == high) {
            seg[ind] = arr[low];
        }
        else {
            int mid = (low + high) / 2;
            build(ind * 2 + 1, low, mid, arr);
            build(ind * 2 + 2, mid + 1, high, arr);
        }
    }

    ll query(int ind, int l, int r, int low, int high) {
        if (lazy[ind] != 0) {
            seg[ind] += lazy[ind];
            if (low != high) {
                lazy[ind * 2 + 1] += lazy[ind];
                lazy[ind * 2 + 2] += lazy[ind];
            }
            lazy[ind] = 0;
        }
        if (low > r || high < l || high < low) return LLONG_MAX;
        else if (low >= l && high <= r) return seg[ind];
        else {

        }
    }
};

int main() {
    ios_base::sync_with_stdio(0);
    cout.tie(0);
    cin.tie(0);

    vector<ll> ms(5);
    ll sum = 0;
    for (int i = 0; i < 5; i++) {
        cin >> ms[i];
        sum += ms[i];
    }

    ll m1, m2;
    cin >> m1 >> m2;

    if (m1 >= sum && m2 >= sum) {
        printf("They both can do it!");
        return 0; 
    }
    else if (m1 >= sum) {
        printf("Vasyl can do it!");
        return 0;
    }
    else if (m2 >= sum) {
        printf("Petro can do it!");
        return 0;
    }

    ll res = -1;

    for (int i = 0; i < (1 << 5); i++) {
        ll first = 0;
        for (int j = 0; j < 5; j++) {
            if (i & (1 << j)) first += ms[j];
        }
        ll second = sum - first;
        if (first <= m1 && second <= m2) {
            res = i;
            break;
        }
    }

    if (res == -1) {
        printf("They can not do it!");
    }
    else {
        printf("They need to work together!\n");
        printf("Vasyl: ");
        for (int i = 0; i < 5; i++) {
            if (res & (1 << i)) {
                printf("%i ", i + 1);
            }
        }
        printf("\n");
        printf("Petro: ");
        for (int i = 0; i < 5; i++) {
            if ((res & (1 << i)) == 0) {
                printf("%i ", i + 1);
            }
        }
    }
}