
#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>

using ll = long long;
using namespace std;
using namespace __gnu_pbds;

typedef tree<ll, null_type, less<ll>, rb_tree_tag, tree_order_statistics_node_update> ordered_set;

struct Fenwick {
    vector<ll> fen;
    vector<ll> arr;
    ll n;

    Fenwick(vector<ll>& a) {
        n = a.size();
        arr.assign(n + 1, 0);
        fen.assign(n + 1, 0);

        for (int i = 1; i <= n; i++) {
            arr[i] = a[i];
            fen[i] += a[i];

            int j = i + (i & (-i));
            if (j <= n) {
                fen[j] += fen[i];
            }
        }
    }

    ll getSum(ll r) {
        int j = r;
        ll res = 0;
        while (j > 0) {
            res += fen[j];
            j -= (j & (-j));
        }
        return res;
    }

    ll query(ll l, ll r) {
        return getSum(r) - getSum(l - 1);
    }

    void update(ll i, ll val) {
        int j = i;
        while (j <= n) {
            fen[j] -= arr[i];
            fen[j] += val;
            j += (j & (-j));
        }
        arr[i] = val;
    }
};


struct Sparse {
    vector<vector<ll>> sp;
    Sparse(vector<ll>& arr) {
        ll n = arr.size();
        sp.assign(n, vector<ll>(log2(n) + 1, 0));
        for (int i = 0; i < n; i++) {
            sp[i][0] = arr[i];
        }

        for (int p = 1; p >= log2(n); p++) {
            for (int i = 0; i <= n - (1 << p); i++) {
                sp[i][p] = min(sp[i][p - 1], sp[i + (1 << (p - 1))][p - 1]);
            }
        }
    }

    ll query(ll l, ll r) {
        ll p = log2(r - l + 1);
        return min(sp[l][p], sp[r - (1 << p) + 1][p]);
    }
};

struct Segment { // for min/max queries
    vector<ll> seg;
    vector<ll> lazy;

    Segment(vector<ll>& arr) {
        ll n = arr.size();
        seg.assign(4 * n, 0);
        lazy.assign(4 * n, 0);
        build(0, 0, n - 1, arr);
    }

    void build(int ind, int low, int high, vector<ll>& arr) {
        if (low == high) {
            seg[ind] = arr[low];
        }
        else {
            int mid = (low + high) / 2;
            build(ind * 2 + 1, low, mid, arr);
            build(ind * 2 + 2, mid + 1, high, arr);
        }
    }

    ll query(int ind, int l, int r, int low, int high) {
        if (lazy[ind] != 0) {
            seg[ind] += lazy[ind];
            if (low != high) {
                lazy[ind * 2 + 1] += lazy[ind];
                lazy[ind * 2 + 2] += lazy[ind];
            }
            lazy[ind] = 0;
        }
        if (low > r || high < l || high < low) return LLONG_MAX;
        else if (low >= l && high <= r) return seg[ind];
        else {

        }
    }
};

const int N = 1e3;

ll n;

ll p[N];
ll q[N];

ll hor[N];
ll ver[N];

bool check(int i, bool main) {
    if (i >= n || i == n - 1 && !main) return true; 
    if (main) {
        if (p[i] % hor[i] != 0) return false;
        ver[i] = p[i] / hor[i];
        return check(i, false);
    }
    else {
        if (q[i] % ver[i] != 0) return false;
        hor[i + 1] = q[i] / ver[i];
        return check(i + 1, true);
    }
}

void printFactors(ll num, bool neg=false) {
    for (int pr = 2; pr <= sqrt(num); pr++) {
        if (num % pr == 0) {
            printf("%i ", pr);
            int cnt = 0;
            while (num % pr == 0) {
                num /= pr;
                cnt++;
            }
            printf("%i\n", neg ? -cnt : cnt);
        }
    }
    if (num != 1) {
        printf("%lld %i\n", num, neg ? -1 : 1);
    }
}

int main() {
    ios_base::sync_with_stdio(0);
    cout.tie(0);
    cin.tie(0);

    
    cin >> n;

    
    for (int i = 0; i < n; i++) cin >> p[i];

    
    for (int i = 0; i < n - 1; i++) cin >> q[i];

    for (int i = 0; i < n; i++) {
        hor[i] = 0;
        ver[i] = 0;
    }

    for (int div = 1; div <= sqrt(p[0]); div++) {
        if (p[0] % div != 0) continue;
        hor[0] = div;
        bool works = check(0, true);
        if (works) break;
        for (int i = 0; i < n; i++) {
            hor[i] = 0;
            ver[i] = 0;
        }
    }

    ll a, b;
    cin >> a >> b;

    swap(a, b);

    if (a == b) {
        printFactors(p[a - 1]);
        return 0;
    }
    else if (a + 1 == b) {
        printFactors(q[a - 1]);
        return 0;
    }
    else if (a == b + 1) {
        if (p[a - 2] == 1 && p[a - 1] == 1) {
            printf("1 1\n");
            return 0;
        }
        if (p[a - 2] != 1) {
            printFactors(p[a - 2], true);
            return 0;
        }
        if (p[a - 1] != 1) {
            printFactors(p[a - 1], true);
            return 0;
        }
        
    }

    ll res = hor[a - 1] * hor[b - 1];
    if (res == 1) {
        printf("1 1\n");
    }
    else {
        printFactors(res);
    }

    
}